@@ -1,6 +1,6 @@
 =head1 NAME
 
-Tk::HListbox - Tk Listbox widget supporting images and text entries, Tk::HList based drop-in replacement for Tk::Listbox.
+Tk::HListbox - Tk Listbox widget supporting images and text entries, Tk::HList-based drop-in replacement for Tk::Listbox.
 
 =for category  Tk Widget Classes
 
@@ -250,9 +250,9 @@ retained).
 
 =item Name:	B<takeFocus>
 
-=item Class:	B<Focus>
+=item Class:	B<TakeFocus>
 
-=item Switch: B<-takefocus> => I<number>
+=item Switch: B<-takefocus>
 
 There are actually three different focusing options:  Specify B<1> to both 
 allow the widget to take keyboard focus itself and to enable grabbing the 
@@ -1196,7 +1196,7 @@ use Tk;
 use Tk::ItemStyle;
 use base qw(Tk::Derived Tk::HList);
 use vars qw($VERSION @Selection $Prev $tixIndicatorArmed);
-$VERSION = '2.5';
+$VERSION = '2.51';
 
 Tk::Widget->Construct('HListbox');
 
@@ -1603,8 +1603,6 @@ sub selectionAnchor {  #SET THE SELECTION ANCHOR (Listbox's version of HList's "
 #a LEGITIMATE ENTRY!!!  THEREFORE WHENEVER WE "activate" AN ENTRY, WE MUST SAVE IT AS "$w->{'_lastactive'}"!:
 sub activate {    #HListbox "anchor" == Listbox "active"!
 	my ($w) = shift;
-#	return  if ($w->{Configure}{'-state'} =~ /d/o);
-
 	my @v = @_;
 	return  unless (defined($v[0]) || $w->{'-showcursoralways'});
 
@@ -1613,15 +1611,17 @@ sub activate {    #HListbox "anchor" == Listbox "active"!
 
 	unless ($w->entrycget($ent, '-state') eq 'disabled' || $w->info('hidden', $ent)) {
 		if (defined($v[0]) && defined($ent)) {
-			if ($w->{'-showcursoralways'} || ($w->{'_hasfocus'} && $w->focusCurrent)) {
-				$w->Tk::HList::anchorSet($ent);
+			my $showcursor = $w->{'-showcursoralways'} || 0;
+			$showcursor = 0  if ($showcursor < 0 && defined($v[1]) && $v[1] == 1);
+			if ($showcursor || ($w->{'_hasfocus'} && $w->focusCurrent)) {
+				$w->Tk::HList::anchorSet($ent);    #THIS SHOWS THE CURSOR
 			} else {
-				$w->Tk::HList::anchorClear($ent);
+				$w->Tk::HList::anchorClear($ent);  #THIS HIDES THE CURSOR
 			}
 			$w->{'_lastactive'} = $w->indexOf($ent);
 		} else {
 			$w->{'_lastactive'} = $w->index('active');
-			$w->Tk::HList::anchorClear();
+			$w->Tk::HList::anchorClear($w->{'_lastactive'});
 		}
 	}
 }
@@ -1876,7 +1876,7 @@ sub getEntryList {    #CONVERT A LIST OF INDICIES TO HList "ENTRIES":
 
 sub indexOf {  #GIVEN A VALID HList "ENTRY", RETURN IT'S RELATIVE (TO ZERO=1ST) Listbox "INDEX":
 	my $next = $_[0]->getFirstEntry;
-	my $indx = '0';
+	my $indx = 0;
 	while (defined($next) && $next =~ /\S/o) {
 		return $indx  if (!defined($_[1]) || $next == $_[1]);
 		$next = $_[0]->info('next', $next);
@@ -1887,7 +1887,8 @@ sub indexOf {  #GIVEN A VALID HList "ENTRY", RETURN IT'S RELATIVE (TO ZERO=1ST)
 
 sub index {    #GIVEN A VALUE "LISTBOX INDEX", RETURN A ZERO-BASED "INDEX" (CONVERTS STUFF LIKE "@x,y", "end". etc:
 	my $w = $_[0];
-	return '0'  unless (defined($_[1]) && $_[1]);
+	return 0  unless (defined($_[1]) && $_[1]);
+
 	if ($_[1] =~ /^\d+$/o) {
 		return $_[1];
 	} elsif ($_[1] =~ /^end/io) {
@@ -1895,9 +1896,7 @@ sub index {    #GIVEN A VALUE "LISTBOX INDEX", RETURN A ZERO-BASED "INDEX" (CONV
 	} elsif ($_[1] =~ /^anchor/o) {
 		return $_[0]->{'_vanchor'};
 	} elsif ($_[1] =~ /^active/o) {
-#		my $ret = ($w->{'-showcursoralways'} || ($w->{'_hasfocus'} && $w->focusCurrent)) ? $_[0]->indexOf($_[0]->info('anchor')) : $w->{'_lastactive'};
-		my $ret = $w->{'_lastactive'};  #ALWAYS RETURN *OUR* ACTIVE, SEE NOTE ABOVE activate() FUNCTION!
-		return $ret;
+		return $w->{'_lastactive'};  #ALWAYS RETURN *OUR* ACTIVE, SEE NOTE ABOVE activate() FUNCTION!
 	} elsif ($_[1] =~ /^\@\d+\,(\d+)/o) {
 		return $_[0]->indexOf($_[0]->nearest($1));
 	}
@@ -2644,7 +2643,7 @@ sub ButtonRelease_1
 		delete $w->{tixindicator};
 		return;
 	}
-	$w->activate($ent);
+	$w->activate($ent, 1);
 	if ($mode =~ /^(?:multiple|extended)/o) {
 		$w->Callback(-browsecmd);
 	} else {
